@@ -15,12 +15,12 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '2.4-3'                              #
+# last changed in version = '2.4-5'                              #
 #                                                                # 
 ##################################################################
 
 pathReaver=/home/user/.reaver
-
+tempLogging=/tmp/cleven.log
 
 [ "$(whoami)" != 'root' ] && ( echo you are using a non-privileged account; exit 1 )
 
@@ -58,9 +58,9 @@ fi
 if [ "$1" == 'getWlanInformation' ]; then 
     if [ -f $2/wlanInfo-01.csv ]; then rm $2/wlanInfo-* ; fi
     airodump-ng -w $2/wlanInfo wlan0 & sleep $3 && kill $!
-    if [ -f /usr/bin/walsh ]; then 
+    if [ -f /usr/bin/wash ]; then 
        if [ -f $pathReaver/wpsInfo.txt ]; then rm $pathReaver/wpsInfo.txt ; fi
-       walsh -f $2/wlanInfo-01.cap -C -o $pathReaver/wpsInfo.txt
+       wash -f $2/wlanInfo-01.cap -C -o $pathReaver/wpsInfo.txt
     fi
 fi 
 
@@ -80,7 +80,16 @@ fi
 #open a new xterm window for the following requests
 
 if [ "$1" == 'capture' ]; then
-    echo $1 $2 $3 $4 $5 "$6" >> /tmp/clevenTest.txt
+
+    echo "CAPTURE options were:" >> $tempLogging
+    echo "   channel: $2 bssid: $3 writeto: $4/capturedData/$5/$6" >> $tempLogging
+    echo " command given was:" >> $tempLogging
+    if [ "$5" == 'WPA' ]; then
+       echo "   airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0" >> $tempLogging
+    else
+       echo "   airodump-ng --ivs --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0" >> $tempLogging       
+    fi
+
     if [ "$5" == 'WPA' ]; then
        airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
     else
@@ -90,18 +99,12 @@ fi
 
 if [ "$1" == 'authenticate' ]; then
 
-    ## 1. Spaces should be handled in the main program 
+    echo "AUTHENTICATE options were:" >> $tempLogging
+    echo "   essid: $2 myMAC: $3" >> $tempLogging
+    echo " command given was:" >> $tempLogging
+    echo "   aireplay-ng -1 5 -q 10 -a $2 -h $3 wlan0" >> $tempLogging
+ 
     aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
-    
-    ## 2. Workaround version for handling spaces
-    # if    [ "$#" == '4' ]; then
-        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
-    # elif  [ "$#" == '5' ]; then
-        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5" wlan0
-    # elif  [ "$#" == '6' ]; then
-        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5 $6" wlan0
-    # fi   
-    echo $1 $2 $3 $4 >> /tmp/clevenTest.txt
 fi 
 
 if [ "$1" == 'deauthenticate' ]; then 
@@ -128,14 +131,18 @@ if  [ "$1" == 'reaver' ]; then
     reaver -i wlan0 -b $2 -c $3 -e $4 -a -E -vv 
 fi 
 
-if  [ "$1" == 'walsh' ]; then 
-    cat /home/user/.reaver/wpsInfo.txt | grep -e ":"
+if  [ "$1" == 'wash' ]; then 
+    cat $pathReaver/wpsInfo.txt | grep -e ":"
 fi 
 
 if  [ "$1" == 'copyReaver' ]; then 
     cp -pr $2/reaver $3 && chmod 755 $3/reaver && if [ -f /usr/bin/reaver ]; then rm /usr/bin/reaver; fi && ln -s $3/reaver /usr/bin/reaver
 fi 
 
-if  [ "$1" == 'copyWalsh' ]; then 
-    cp -pr $2/walsh $3 && chmod 755 $3/walsh && if [ -f /usr/bin/walsh ]; then rm /usr/bin/walsh; fi && ln -s $3/walsh /usr/bin/walsh
+if  [ "$1" == 'copyWash' ]; then 
+    cp -pr $2/wash $3 && chmod 755 $3/wash && if [ -f /usr/bin/wash ]; then rm /usr/bin/wash; fi && ln -s $3/wash /usr/bin/wash
+fi 
+
+if  [ "$1" == 'copyReaverDB' ]; then 
+    cp -pr $2/reaver.db $3 && chmod 755 $3/reaver.db;
 fi 
