@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '2.4'
-Build = '3'
+Build = '5'
 
 import sys
 import os
@@ -41,7 +41,8 @@ folderKeys           = 'keys'
 folderDictionaries   = 'dictionaries'
 folderCapturedData   = 'capturedData'
 reaverBinary         = 'reaver'
-walshBinary          = 'walsh'
+reaverDatabase       = 'reaver.db'
+washBinary           = 'wash'
 
 ##############################################################
 
@@ -138,7 +139,7 @@ class clevenCapture(QtGui.QMainWindow):
 
        if reaverAvailability == False:
           self.ui.reaverButton.setHidden(True)
-       if walshAvailability == False:
+       if washAvailability == False:
           self.ui.wpsRadio.setHidden(True)
        
        self.ui.captureButton.setEnabled(False)
@@ -198,13 +199,16 @@ class clevenCapture(QtGui.QMainWindow):
        else:
           encryption = "WPA"      
 
-       if self.ui.wpsRadio.isChecked():
+       if self.ui.wpsRadio.isChecked(): ##FIX splitting for new version of wash
           values = []
-          rValues = os.popen('sudo %s/%s walsh' %(pathMain, helperScript)).read()
+          rValues = os.popen('sudo %s/%s wash' %(pathMain, helperScript)).read()
           rValues = rValues.split("\n")                     ##split them to create an entry for each in the list
-          for i in rValues:                                 ## iterate on the values stored in the list
-             values.append(i[18:].lstrip(" ").rstrip(" "))  ## trim the first 18 characters (i.e. the MAC) and spaces from left and right sides.
-          # print 'The WPS list is:\n',values
+          rValues = filter(None, rValues)                   ##remove unknown (empty)
+          for i in rValues:                                 ##iterate on the values stored in the list
+             newList = i.split()                            ##split each line into a list
+             newValue = newList[4]                          ##keep the 5th element only
+             values.append(newValue)                        ##append the AP into a new list
+          # print 'The WPS clean list is:\n',values
        else:
           values = os.popen('sudo %s/%s readESSIDs %s %s' %(pathMain, helperScript, pathStorage, encryption)).read()
           values = values.lstrip(" ")                       ##remove trailing space from first ESSID
@@ -323,7 +327,7 @@ class clevenCapture(QtGui.QMainWindow):
        '''Opens an xterm window that sends authentication packets.'''
        
        # print "authenticate options: ", essid, bssid, myMAC
-       os.system('osso-xterm -e "sudo %s/%s authenticate %s %s \"%s\" " &' % (pathMain, helperScript, bssid, myMAC, essid))
+       os.system('osso-xterm -e "sudo %s/%s authenticate %s %s" &' % (pathMain, helperScript, bssid, myMAC))
 
     def executeInjection(self):
        '''Opens an xterm window that sends injection packets.'''
@@ -348,16 +352,16 @@ class clevenConfigureDrivers(QtGui.QDialog):
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
        
        ##Connect the buttons for the monitoring drivers
-       QtCore.QObject.connect(self.ui.enableMonitor, QtCore.SIGNAL('clicked()'), self.enableMonitor)
-       QtCore.QObject.connect(self.ui.disableMonitor, QtCore.SIGNAL('clicked()'), self.disableMonitor)
-       QtCore.QObject.connect(self.ui.enableInjection, QtCore.SIGNAL('clicked()'), self.enableInjection)
-       QtCore.QObject.connect(self.ui.disableInjection, QtCore.SIGNAL('clicked()'), self.disableInjection)
-       QtCore.QObject.connect(self.ui.macButton, QtCore.SIGNAL('clicked()'), self.setMACinterfaceValue)
-       QtCore.QObject.connect(self.ui.randomButton, QtCore.SIGNAL('clicked()'), self.setMACrandomValue)
-       QtCore.QObject.connect(self.ui.WLAN, QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
-       QtCore.QObject.connect(self.ui.GPRS, QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
-       QtCore.QObject.connect(self.ui.ANY, QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
-       QtCore.QObject.connect(self.ui.ASK, QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
+       QtCore.QObject.connect(self.ui.enableMonitor,     QtCore.SIGNAL('clicked()'), self.enableMonitor)
+       QtCore.QObject.connect(self.ui.disableMonitor,    QtCore.SIGNAL('clicked()'), self.disableMonitor)
+       QtCore.QObject.connect(self.ui.enableInjection,   QtCore.SIGNAL('clicked()'), self.enableInjection)
+       QtCore.QObject.connect(self.ui.disableInjection,  QtCore.SIGNAL('clicked()'), self.disableInjection)
+       QtCore.QObject.connect(self.ui.macButton,         QtCore.SIGNAL('clicked()'), self.setMACinterfaceValue)
+       QtCore.QObject.connect(self.ui.randomButton,      QtCore.SIGNAL('clicked()'), self.setMACrandomValue)
+       QtCore.QObject.connect(self.ui.WLAN,              QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
+       QtCore.QObject.connect(self.ui.GPRS,              QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
+       QtCore.QObject.connect(self.ui.ANY,               QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
+       QtCore.QObject.connect(self.ui.ASK,               QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
        
        ##Get and populate the UI with the current info 
        self.getKernelVersion()
@@ -823,7 +827,7 @@ class clevenStartup(QtGui.QDialog):
        self.step = self.step + 1
        self.ui.progressBarStart.setValue(self.step)
     
-class clevenMain(): ## TODO: add a check for reaver directory
+class clevenMain():
 
     ##Check with what priviledges the GUI has been executed.
     if os.geteuid() == 0:
@@ -844,18 +848,21 @@ class clevenMain(): ## TODO: add a check for reaver directory
     else:
        pass
     
-    global reaverAvailability, walshAvailability
+    global reaverAvailability, washAvailability
     reaverAvailability = False
-    walshAvailability = False
+    washAvailability = False
     
-    ##Check if reaver and/or walsh is available in the home directory:
+    ##Check if reaver and/or wash is available in the home directory:
     if os.path.exists(pathReaver):
        if os.path.isfile(pathReaver + '/' + reaverBinary):
           if os.WEXITSTATUS(os.system('sudo %s/%s copyReaver %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
              print 'found Reaver binary and made a copy'
-       if os.path.isfile(pathReaver + '/' + walshBinary):
-          if os.WEXITSTATUS(os.system('sudo %s/%s copyWalsh %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
-             print 'found Walsh binary and made a copy'
+       if os.path.isfile(pathReaver + '/' + washBinary):
+          if os.WEXITSTATUS(os.system('sudo %s/%s copyWash %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
+             print 'found Wash binary and made a copy'
+       if os.path.isfile(pathReaver + '/' + reaverDatabase):
+          if os.WEXITSTATUS(os.system('sudo %s/%s copyReaverDB %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
+             print 'found Reaver database and made a copy'
 
     ##Check if reaver is available to the application:
     if os.path.isfile(pathMain + '/' + reaverBinary):
@@ -863,12 +870,12 @@ class clevenMain(): ## TODO: add a check for reaver directory
        reaverAvailability = True
        print 'Reaver is available for usage..'
        
-    ##Check if walsh is available to the application:
-    if os.path.isfile(pathMain + '/' + walshBinary):
+    ##Check if wash is available to the application:
+    if os.path.isfile(pathMain + '/' + washBinary):
        os.path.exists(pathReaver) or os.mkdir(pathReaver)
-       walshAvailability = True
-       print 'Walsh is available for usage..'
-    
+       washAvailability = True
+       print 'Wash is available for usage..'
+       
     app = QtGui.QApplication(sys.argv)
     myapp = clevenMainWindow()
     myapp.show()
